<!doctype html>
<html lang="en">
    <head>
        <meta charset="utf-8">
        <title>{{title}} | {{blog_title}}</title>
        <meta name="viewport" content="width=device-width, initial-scale=1">
        <link rel="stylesheet" href="../css/normalize.css">
        <link rel="stylesheet" href="../css/monoblue.css">
        <link href="../css/prism.css" rel="stylesheet">
        <link href="http://fonts.googleapis.com/css?family=Open+Sans:400,400italic,600" rel="stylesheet" type="text/css">
    </head>
    <body>
        <div class="container single">
            <h1 id="blog-title"><a href="../">{{blog_title}}</a></h1>
            <div class="post">
                <div class="post-title-section">
                    <h2 class="post-title">{{title}}</h2>
                    <div class="post-tags">{{tags}}</div>
                    <h3 class="post-date">{{date}}</h3>
                </div>
            {{content}}
            </div>
            <div class="social-plugins">
                <div class="fb-like" data-layout="button_count" data-action="like" data-show-faces="false" data-share="false"></div>
                <a href="https://twitter.com/share" class="twitter-share-button" data-dnt="true">Tweet</a>
                <div class="g-plusone" data-size="medium"></div>
            </div>
        </div>
        <a href="../" id="floating-home">&lt;&lt; Home</a>
        <script src="../js/prism.js"></script>
        <!-- G +1 -->
        <script src="https://apis.google.com/js/platform.js" async defer></script>
        <!-- Twitter -->
        <script>!function(d,s,id){{var js,fjs=d.getElementsByTagName(s)[0],p=/^http:/.test(d.location)?'http':'https';if(!d.getElementById(id)){{js=d.createElement(s);js.id=id;js.src=p+'://platform.twitter.com/widgets.js';fjs.parentNode.insertBefore(js,fjs);}}}}(document, 'script', 'twitter-wjs');</script>
        <!-- FB -->
        <script>(function(d, s, id) {{
         var js, fjs = d.getElementsByTagName(s)[0];
         if (d.getElementById(id)) return;
         js = d.createElement(s); js.id = id;
         js.src = "//connect.facebook.net/en_US/sdk.js#xfbml=1&version=v2.0";
         fjs.parentNode.insertBefore(js, fjs);
        }}(document, 'script', 'facebook-jssdk'));</script>
    </body>
</html>
