<div class="post">
    <div class="post-title-section">
        <h2 class="post-title"><a href="{{slug}}">{{title}}</a></h2>
        <div class="post-tags">{{tags}}</div>
        <h3 class="post-date">{{date}}</h3>
    </div>
    {{peek}}
    <div><strong><a href="{{slug}}">Read more &gt;&gt;</a></strong></div>
</div>
<hr>
