* {
    box-sizing: border-box;
}

body {
    font-size: 18px;
    font-family: 'Open Sans', sans-serif;
    background-color: #fff;
}

a {
    color: #00617F;
    text-decoration: none;
}

a:hover {
    color: #00B3CC;
}

.container {
    margin: auto;
}

.container.column {
    margin-left: 25%;
    padding: 2em;
    width: 75%;
}

.sidebar-container {
    bottom: 0;
    position: fixed;
    top: 0;
    width: 25%;
    background-color: #00617F;
    box-shadow: 0 0 3px 3px #aaa;
}

.sidebar {
    padding: 1em;
    color: #fff;
}

.sidebar p {
    font-size: 1.2em;
}

.sidebar hr {
    border: none;
    border-top: 1px solid #eee;
}

.container.column hr {
    border: none;
    border-top: 1px solid #666;
    margin: 2em 0;
}

.container.column h2,
.container.column h3 {
    margin: .3em 0;
}

.container.single {
    margin-bottom: 5em;
    width: 70%;
}

.container.single h2 {
    font-size: 2em;
}

.container.single #blog-title {
    text-align: center;
}

.container .post {
    line-height: 1.5em;
}

.tag {
    font-size: 0.8em;
    color: #666;
    padding: 0.2em 0.5em;
    background-color: #eee;
    border-radius: 2px;
    margin-right: 5px;
}

.post a.tag:hover {
    background-color: #ddd;
    color: #666;
}

#floating-home {
    display: block;
    position: fixed;
    top: 0;
    right: 0;
    background-color: #00617F;
    color: #fff;
    padding: 0.7em 1em;
    border-radius: 1px;
}

#floating-home:hover {
    background-color: #00B3CC;
}

pre[class*="language-"],
blockquote {
    border-left: 7px solid #00617F;
}

blockquote {
    margin-left: 0;
    padding-left: 1em;
}

.social-plugins {
    margin-top: 2em;
}

.social-plugins div,
.social-plugins iframe {
    width: 80px;
    float: left;
}

.social-plugins .fb-like {
    margin-top: -4px;
}

code {
    background-color: #f4f4f4;
    border: 1px solid #ccc;
    border-radius: 3px;
    color: #333;
    font-family: 'Ubuntu Mono', Consolas, Monaco, monospace;
    padding: .1em .2em;
}

pre code {
    background-color: transparent;
    border: none;
    padding: 0;
}

@media (max-width: 800px) {
    #floating-home {
        position: static;
    }

    .container.column {
        margin: 0;
        width: 100%;
    }

    .container.single {
        width: 90%;
    }

    .container.single hr {
        margin: 1em 0;
    }

    .sidebar-container {
        padding: 0;
        position: static;
        text-align: center;
        width: 100%;
    }

    .sidebar {
        font-size: .8em;
    }

    .sidebar h1,
    .sidebar h2 {
        margin: .2em
    }
}
